.. webapi-error::
   :title: Ship-It Revocation Error
   :instance: reviewboard.webapi.errors.REVOKE_SHIP_IT_ERROR

   An error occurred while revoking the Ship It for a review. This may be
   an error provided by an extension.
